%
%	Estimate x from an estimate of phi and the support of x
%	for purely nonlinear polynomials where phi(1:n) = 0 ~= x   
%
%	(works also for polynomials with a linear part, but slightly slower.
%		This is why we do not call phi2x() from the polyBP functions
%		that simply set x = phi(1:n). )
%	
%	Warning: result of SL1L2M might have nonzero phi(1:n) for purely 
%			 nonlinear polynomials since ||W_j phi|| for nonzero x_j is not minimized. 
%				=> explicitly set phi(1:n) = 0 before applying phi2x(). 
%					(we don't do it here since there might be cases 
%					 with only a subset of variables concerned)
%
function x = phi2x(phi, A, supp_x, n, degree, alpha) 
	
	dosigns = 0;
	
	x = zeros(n,1);
	x2 = zeros(n,1);
	
	if size(supp_x,1) > size(supp_x,2)
		supp_x = supp_x';
	end
	
	Al1 = sum(abs(A));
	
	if sum(Al1(supp_x)) ~= 0
		% Linear part is here, so just use that
		x = phi(1:n);

	else
		% no linear part
		
		if degree > 2    % make sure an odd power > 2 exists
			
			% For each nonzero x_j
			for j=supp_x
		
				% find the smallest odd power with nonzero column
				p=1;
				k = indexof(j,2*p+1,alpha);
				
				while p <= (degree-1)/2 & Al1(k) == 0
					k = indexof(j,2*p+1,alpha);			
				end
			
				if Al1(k) > 0
					% nonzero odd power found
					x(j) = nthroot( phi(k),  (2*p+1) );
				
				else
					% only even powers... should check the signs with bilinear terms....
				
					% assume smallest even power (2) is nonzero (TO DO: other cases...)
					x2(j) = phi(indexof(j,2,alpha)); 
					
					dosigns = 1;
				
				end
			
			end
		else
			for j=supp_x
				x2(j) = phi(indexof(j,2,alpha));
			end
			dosigns = 1;
				
		end
		
	end


	% Check signs if needed
	if dosigns
		x2 (x2 < 0) = 0;
	
		s = zeros(n,n);
		
		% need to check signs for even degrees
		
		% First pass to set signs without choices
		for j = supp_x
			s(j,j) = 1;
			
			if x(j) == 0 
				% x_j not assigned yet
				for i= supp_x
					if i~=j
						s(j,i) = sign( phi(indexofij(j,i,alpha) ) );
						s(i,j) = s(j,i); 
						if x(i) ~= 0
							% x_i already determined so
							% directly set sign of x_j with sign of x_i
							x(j) = sign(x(i)) * s * sqrt(x2(j)) ;
							break;  
						end
					end
				end
				
			end
		end
		
		% test combinations with a "we're lucky algo"
		% (exact method not implemented yet...)
		for j = supp_x
			if x(j) == 0 
				% x_j not assigned yet
				
				% try positive
				x(j) = sqrt(x2(j));
								
				for i= supp_x
					if i~=j
						if s(j,i) ~= 0 
							% set x(i) accordingly
							x(i) = sign(x(j)) * s(j,i) * sqrt(x2(i)) ;
						end
					end
				end
				
			end
		end
		
		% Check if the lucky solution works...
		if sum(sum(sign(x) * sign(x)' ~= s)) > 0
			%sign(x) * sign(x)' 
			%s
			warning('Wrong estimate of x by phi2x (signs do not match)...');
		end
	end

end


% Find index of x_i x_j
function k = indexofij(i, j, alpha)
	k=1;

	multiidx = zeros(1,size(alpha,2));
	multiidx([i,j]) = 1;
	while k <= size(alpha,1) & any(alpha(k,:) ~= multiidx)
		k = k +1;
	end
	
end
